@@ -26,7 +26,7 @@ from lxml import etree as ET
 import numpy as np
 try:
     import skimage.data
-    import skimage.measure
+    import skimage.metrics
     _HAVE_SCIKIT_IMAGE = True
 except ModuleNotFoundError:
     _HAVE_SCIKIT_IMAGE = False
@@ -1104,6 +1104,7 @@ class TestJp2k(fixtures.TestCommon):
 
         self.assertEqual(j.layer, 0)
 
+    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
     def test_thread_support(self):
         """
         SCENARIO:  Set a non-default thread support value.
@@ -1124,6 +1125,7 @@ class TestJp2k(fixtures.TestCommon):
 
         self.assertTrue(delta1 < delta0)
 
+    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
     def test_thread_support_on_openjpeg_lt_220(self):
         """
         SCENARIO:  Set number of threads on openjpeg < 2.2.0
@@ -1134,6 +1136,7 @@ class TestJp2k(fixtures.TestCommon):
             with self.assertRaises(RuntimeError):
                 glymur.set_option('lib.num_threads', 4)
 
+    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
     @patch('glymur.lib.openjp2.has_thread_support')
     def test_thread_support_not_compiled_into_library(self, mock_ts):
         """
@@ -1226,6 +1229,24 @@ class TestJp2k_write(fixtures.MetadataBase):
         os.unlink(cls.single_channel_j2k)
         os.unlink(cls.single_channel_jp2)
 
+    @unittest.skipIf(os.cpu_count() < 2, "makes no sense if 2 cores not there")
+    def test_threads(self):
+        """
+        SCENARIO:  Attempt to encode with threading support.  This feature is
+        new as of openjpeg library version 2.4.0.
+
+        EXPECTED RESULT:  In library versions prior to 2.4.0, a warning is
+        issued.
+        """
+        glymur.set_option('lib.num_threads', 2)
+        with open(self.temp_jp2_filename, mode='wb') as tfile:
+            with warnings.catch_warnings(record=True) as w:
+                Jp2k(tfile.name, data=self.jp2_data)
+                if glymur.version.openjpeg_version >= '2.4.0':
+                    self.assertEqual(len(w), 0)
+                else:
+                    self.assertEqual(len(w), 1)
+
     def test_no_jp2c_box_in_outermost_jp2_list(self):
         """
         SCENARIO:  A JP2 file is encountered without a JP2C box in the outer-
@@ -1307,7 +1328,9 @@ class TestJp2k_write(fixtures.MetadataBase):
             # warning
             warnings.simplefilter('ignore')
             psnr = [
-                skimage.measure.compare_psnr(skimage.data.camera(), d[j])
+                skimage.metrics.peak_signal_noise_ratio(
+                    skimage.data.camera(), d[j]
+                )
                 for j in range(4)
             ]
 
@@ -2343,9 +2366,22 @@ class TestReadArea(unittest.TestCase):
         self.assertEqual(ssdata.shape, (1, 1, 3))
 
     def test_NR_DEC_p1_06_j2k_75_decode(self):
-        # Image size would be 0 x 0.
-        with self.assertRaises(InvalidJp2kError):
-            self.j2k[9:12:4, 9:12:4]
+        """
+        SCENARIO:  Try to read an image area with an impossible stride.
+
+        EXPECTED RESULT:  An error is raised.
+        """
+        if glymur.version.openjpeg_version >= '2.4.0':
+            # The library catches this on its own.
+            expected_error = glymur.lib.openjp2.OpenJPEGLibraryError
+        else:
+            # Image size would be 0 x 0.  We have to manually detect this.
+            expected_error = InvalidJp2kError
+        with self.assertRaises(expected_error):
+            with warnings.catch_warnings():
+                # Only openjpeg 2.4.0 issues warnings
+                warnings.simplefilter('ignore')
+                self.j2k[9:12:4, 9:12:4]
 
     def test_NR_DEC_p0_04_j2k_85_decode(self):
         actual = self.j2k[:256, :256]
